@@ -2,6 +2,10 @@ class JsonPatchError(Exception):
     pass
 
 
+class JsonDocumentMissing(JsonPatchError):
+    pass
+
+
 class JsonPatchInvalidError(JsonPatchError):
     pass
 
@@ -12,6 +16,7 @@ class JsonPatchUnsupportedOperationError(JsonPatchError):
 
 __all__ = [
     "JsonPatchError",
+    "JsonDocumentMissing",
     "JsonPatchInvalidError",
     "JsonPatchUnsupportedOperationError",
 ]
