@@ -1,4 +1,6 @@
-import json
+from pathlib import Path
+
+import yaml
 
 from ..ctypes import (
     StringOrFilePath,
@@ -10,10 +12,15 @@ from ..exceptions import JsonPatchInvalidError
 
 class Loader:
     def __call__(self, s_or_fp: StringOrFilePath, /, **kwargs) -> JsonPatchDocument:
-        if isinstance(s_or_fp, (bytes, str)):
-            result = json.loads(s_or_fp, **kwargs)
-        else:
-            result = json.load(s_or_fp, **kwargs)
+        if not isinstance(s_or_fp, (bytes, str)):
+            kwargs.setdefault("encoding", "utf-8")
+            kwargs.setdefault("errors", "ignore")
+            s_or_fp = Path(s_or_fp).read_text(**kwargs)
+
+        if not isinstance(s_or_fp, str):
+            raise JsonPatchInvalidError()
+
+        result = yaml.safe_load(s_or_fp)
 
         if not isinstance(result, list):
             raise JsonPatchInvalidError()
